package cmd

import flags "github.com/orus-io/go-flags"

// Options holds some generic options.
type Options struct {
	ConfigFile func(string) error `long:"config" short:"c" env:"CONFIG" no-ini:"t" description:"A configuration file. This flag should be first on the command line"`

	Env string `long:"environment" env:"ENVIRONMENT" ini-name:"environment" description:"dev, production, test whatever"`

	LogLevel  func(string) error `long:"log-level" env:"LOG_LEVEL" ini-name:"log-level" choice:"trace" choice:"debug" choice:"info" choice:"warn" choice:"error" choice:"fatal" choice:"panic" choice:"auto" default:"auto" description:"log level. 'auto' selects 'info' when stdout is a tty, 'error' otherwise."`
	LogFormat func(string)       `long:"log-format" env:"LOG_FORMAT" ini-name:"log-format" choice:"json" choice:"pretty" choice:"auto" default:"auto" description:"Logs format. 'auto' selects 'pretty' if stdout is a tty."`
	Verbose   func()             `short:"v" long:"verbose" no-ini:"t" description:"Increase log verbosity. Can be repeated"`

	Dsn       string `long:"dsn" env:"DSN" ini-name:"dsn" description:"DSN of the database" required:"t"`
	DBMaxConn int    `long:"db-max-conn" env:"DB_MAX_CONN" ini-name:"db-max-conn" description:"Database max connection" default:"0"`

	BaseURL string `long:"base-url" env:"BASE_URL" ini-name:"base-url" description:"Public facing URL of the service. Used to build urls sent to the end users"`
}

// NewOptions creates a Options.
func NewOptions(parser *flags.Parser) *Options {
	o := Options{}
	o.setupLogging()
	o.ConfigFile = parseFile(parser)

	return &o
}
